@@ -1,5 +1,6 @@
 import os
 import sys
+from typing import List
 
 project_root = os.path.dirname(
     os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
@@ -16,7 +17,11 @@ import vessl
 from vessl.cli._base import VesslGroup
 from vessl.cli._util import prompt_choices
 from vessl.cli.dataset import cli as dataset_cli
-from vessl.cli.experiment import cli as experiment_cli
+from vessl.cli.experiment import (
+    cli as experiment_cli,
+    create as experiment_create,
+    logs as experiment_logs,
+)
 from vessl.cli.kernel_cluster import cli as kernel_cluster_cli
 from vessl.cli.kernel_image import cli as kernel_image_cli
 from vessl.cli.kernel_resource_spec import cli as kernel_resource_spec_cli
@@ -32,12 +37,12 @@ from vessl.util.exception import (
     InvalidOrganizationError,
     InvalidProjectError,
     InvalidTokenError,
-    SavvihubApiException,
+    VesslApiException,
 )
 
 # Configure Sentry
 sentry_sdk.init(
-    "https://e46fcd750b3a443fbd5b9dbc970e4ecf@o386227.ingest.sentry.io/5911639",
+    os.environ.get("SENTRY_DSN", "https://e46fcd750b3a443fbd5b9dbc970e4ecf@o386227.ingest.sentry.io/5911639"),
     traces_sample_rate=1.0,
 )
 ignore_logger("vessl_logger")
@@ -91,41 +96,61 @@ def configure(
         return
 
     try:
-        vessl.update_access_token(
+        vessl.configure_access_token(
             access_token=access_token,
             credentials_file=credentials_file,
             force_update=renew_token,
         )
     except InvalidTokenError:
-        vessl.update_access_token(force_update=True)
+        vessl.configure_access_token(force_update=True)
 
     try:
-        vessl.update_organization(
+        vessl.configure_organization(
             organization_name=organization, credentials_file=credentials_file
         )
     except InvalidOrganizationError:
         organization_name = prompt_organizations()
-        vessl.update_organization(organization_name)
+        vessl.configure_organization(organization_name)
 
     try:
-        vessl.update_project(project_name=project, credentials_file=credentials_file)
+        vessl.configure_project(project_name=project, credentials_file=credentials_file)
     except InvalidProjectError:
         projects = vessl.list_projects()
         if len(projects) == 0:
             return
 
         project_name = prompt_choices("Default project", [x.name for x in projects])
-        vessl.update_project(project_name)
+        vessl.configure_project(project_name)
 
     print(f"Welcome, {vessl.vessl_api.user.display_name}!")
 
 
+@configure.vessl_command(hidden=True)
+@click.pass_context
+@click.argument("extras", nargs=-1)
+def run(ctx, extras: List[str]):
+    args = []
+    args.extend(["--command", ' '.join(extras)])
+    args.extend(["--upload-local-git-diff", "false"])
+    args.extend(["--working-dir", "/home/vessl/local/"])
+    args.extend(["--upload-local-file", ".:/home/vessl/local/"])
+
+    ctx.params = {}
+    ctx.args = experiment_create.parse_args(ctx, args)
+    ctx.forward(experiment_create)
+
+    experiment = ctx.obj.get("experiment")
+    ctx.params = {}
+    ctx.args = experiment_logs.parse_args(ctx, [experiment.name, "--follow"])
+    ctx.forward(experiment_logs)
+
+
 @configure.vessl_command()
 @click.argument("organization", type=click.STRING, required=False)
 def organization(organization: str):
     if organization is None:
         organization = prompt_organizations()
-    vessl.update_organization(organization)
+    vessl.configure_organization(organization)
     print(f"Saved to {DEFAULT_CONFIG_PATH}.")
 
 
@@ -140,7 +165,7 @@ def project(project: str):
             return
 
         project = prompt_choices("Default project", [x.name for x in projects])
-    vessl.update_project(project)
+    vessl.configure_project(project)
     print(f"Saved to {DEFAULT_CONFIG_PATH}.")
 
 
@@ -162,7 +187,7 @@ def list():
             user = vessl.vessl_api.get_my_user_info_api()
             username = user.username
             email = user.email
-        except SavvihubApiException as e:
+        except VesslApiException as e:
             pass
 
     print(
@@ -185,6 +210,7 @@ cli.add_command(ssh_key_cli)
 cli.add_command(sweep_cli)
 cli.add_command(volume_cli)
 cli.add_command(workspace_cli)
+cli.add_command(run)
 
 
 if __name__ == "__main__":
