@@ -1,22 +1,25 @@
 import json
 
 from openapi_client.exceptions import ApiException
+from vessl._version import __VERSION__
 
-DEFAULT_ERROR_MESSAGE = "An unexpected exception occurred. Use VESSL_LOG=DEBUG to view stack trace. (`pip install --upgrade vessl` might resolve this issue.)"
+DEFAULT_ERROR_MESSAGE = (
+    "An unexpected exception occurred. Use VESSL_LOG=DEBUG to view stack trace. "
+    "(CLI version: %s)\n"
+    "(`pip install --upgrade vessl` might resolve this issue.)" % __VERSION__
+)
 
 
-class SavvihubException(Exception):
+class VesslException(Exception):
     def __init__(self, message=DEFAULT_ERROR_MESSAGE, exit_code=1):
         self.message = message
         self.exit_code = exit_code
         super().__init__(message)
 
 
-class SavvihubApiException(SavvihubException):
+class VesslApiException(VesslException):
     @classmethod
-    def convert_api_exception(
-        cls, api_exception: ApiException
-    ) -> "SavvihubApiException":
+    def convert_api_exception(cls, api_exception: ApiException) -> "VesslApiException":
         try:
             body = json.loads(api_exception.body)
         except json.JSONDecodeError:
@@ -45,53 +48,61 @@ class SavvihubApiException(SavvihubException):
         return cls(message=message)
 
 
-class GitError(SavvihubException):
+class GitError(VesslException):
     pass
 
 
-class TimeoutError(SavvihubException):
+class TimeoutError(VesslException):
     pass
 
 
-class InvalidDatasetError(SavvihubException):
+class InvalidDatasetError(VesslException):
     pass
 
 
-class InvalidKernelImageError(SavvihubException):
+class InvalidKernelClusterError(VesslException):
     pass
 
 
-class InvalidKernelResourceSpecError(SavvihubException):
+class InvalidKernelImageError(VesslException):
     pass
 
 
-class InvalidOrganizationError(SavvihubException):
+class InvalidKernelResourceSpecError(VesslException):
     pass
 
 
-class InvalidExperimentError(SavvihubException):
+class InvalidOrganizationError(VesslException):
     pass
 
 
-class InvalidProjectError(SavvihubException):
+class InvalidExperimentError(VesslException):
     pass
 
 
-class InvalidTokenError(SavvihubException):
+class InvalidProjectError(VesslException):
     pass
 
 
-class InvalidVolumeFileError(SavvihubException):
+class InvalidTokenError(VesslException):
     pass
 
 
-class InvalidVolumeMountError(SavvihubException):
+class InvalidVolumeFileError(VesslException):
     pass
 
 
-class InvalidWorkspaceError(SavvihubException):
+class InvalidVolumeMountError(VesslException):
     pass
 
 
-class InvalidParamsError(SavvihubException):
+class InvalidWorkspaceError(VesslException):
+    pass
+
+
+class InvalidParamsError(VesslException):
+    pass
+
+
+class InvalidTypeError(VesslException):
     pass
